"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var plugin_db_1 = require("../../../persistence/plugin-db");
var model_1 = require("./model");
var RecognizersStateStoreDb = (function () {
    function RecognizersStateStoreDb() {
        this.tableName = model_1.recognizersStateModel.name;
    }
    RecognizersStateStoreDb.prototype.isActive = function (recognizer) {
        return __awaiter(this, void 0, void 0, function () {
            var recognizerData;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.getRecognizerData(recognizer)];
                    case 1:
                        recognizerData = _a.sent();
                        if (!recognizerData) {
                            return [2, false];
                        }
                        return [2, recognizerData.active];
                }
            });
        });
    };
    RecognizersStateStoreDb.prototype.getStartOptions = function (recognizer) {
        return __awaiter(this, void 0, void 0, function () {
            var isActive, recognizerData;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.isActive(recognizer)];
                    case 1:
                        isActive = _a.sent();
                        if (!isActive) {
                            return [2, null];
                        }
                        return [4, this.getRecognizerData(recognizer)];
                    case 2:
                        recognizerData = _a.sent();
                        if (!recognizerData) {
                            return [2, null];
                        }
                        return [2, JSON.parse(recognizerData.startOptions)];
                }
            });
        });
    };
    RecognizersStateStoreDb.prototype.markAsActive = function (recognizer, startOptions) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.updateStatus(recognizer, true, startOptions)];
                    case 1:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    RecognizersStateStoreDb.prototype.markAsInactive = function (recognizer) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.updateStatus(recognizer, false)];
                    case 1:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    RecognizersStateStoreDb.prototype.getLastActivity = function (recognizer) {
        return __awaiter(this, void 0, void 0, function () {
            var instance, rows, lastActivity;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.db()];
                    case 1:
                        instance = _a.sent();
                        return [4, instance
                                .query("select")
                                .where(["id", "=", recognizer])
                                .exec()];
                    case 2:
                        rows = _a.sent();
                        if (rows.length === 0) {
                            return [2, null];
                        }
                        lastActivity = rows[0].lastActivity;
                        return [2, lastActivity ? lastActivity : null];
                }
            });
        });
    };
    RecognizersStateStoreDb.prototype.updateLastActivity = function (recognizer, activity) {
        return __awaiter(this, void 0, void 0, function () {
            var isActive, instance;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.isActive(recognizer)];
                    case 1:
                        isActive = _a.sent();
                        if (!isActive) {
                            return [2, null];
                        }
                        return [4, this.db(this.tableName + ".lastActivity")];
                    case 2:
                        instance = _a.sent();
                        return [4, instance
                                .query("upsert", activity)
                                .where(["id", "=", recognizer])
                                .exec()];
                    case 3:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    RecognizersStateStoreDb.prototype.updateStatus = function (recognizer, active, startOptions) {
        if (startOptions === void 0) { startOptions = {}; }
        return __awaiter(this, void 0, void 0, function () {
            var instance;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.db()];
                    case 1:
                        instance = _a.sent();
                        return [4, instance
                                .query("upsert", {
                                id: recognizer,
                                active: active,
                                startOptions: JSON.stringify(startOptions),
                                lastActivity: null,
                            })
                                .exec()];
                    case 2:
                        _a.sent();
                        return [2];
                }
            });
        });
    };
    RecognizersStateStoreDb.prototype.getRecognizerData = function (recognizer) {
        return __awaiter(this, void 0, void 0, function () {
            var instance, rows;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4, this.db()];
                    case 1:
                        instance = _a.sent();
                        return [4, instance
                                .query("select")
                                .where(["id", "=", recognizer])
                                .exec()];
                    case 2:
                        rows = _a.sent();
                        if (rows.length === 0) {
                            return [2, null];
                        }
                        return [2, rows[0]];
                }
            });
        });
    };
    RecognizersStateStoreDb.prototype.db = function (tableName) {
        if (tableName === void 0) { tableName = this.tableName; }
        return plugin_db_1.pluginDb.instance(tableName);
    };
    return RecognizersStateStoreDb;
}());
exports.recognizersStateStoreDb = new RecognizersStateStoreDb();
//# sourceMappingURL=store.js.map